@@ -7,9 +7,9 @@ from torch import nn
 import torch
 from ..layers import EmbeddingLayer, MLP_Layer
 from ..utils import get_feature_num, get_linear_input
+from ..base_model import BaseModel
 
-
-class AOANet(nn.Module):
+class AOANet(BaseModel):
     def __init__(self,
                  embedding_dim=32,
                  dnn_hidden_units=[64, 64, 64],
@@ -17,14 +17,12 @@ class AOANet(nn.Module):
                  num_subspaces = 4,
                  loss_fun='torch.nn.BCELoss()',
                  enc_dict=None):
-        super(AOANet, self).__init__()
+        super(AOANet, self).__init__(enc_dict,embedding_dim)
 
-        self.embedding_dim = embedding_dim
         self.dnn_hidden_units = dnn_hidden_units
         self.loss_fun = eval(loss_fun)
         self.enc_dict = enc_dict
 
-        self.embedding_layer = EmbeddingLayer(enc_dict=self.enc_dict, embedding_dim=self.embedding_dim)
         self.num_sparse, self.num_dense = get_feature_num(self.enc_dict)
 
         self.dnn = MLP_Layer(input_dim=self.embedding_dim * self.num_sparse + self.num_dense,
@@ -35,6 +33,7 @@ class AOANet(nn.Module):
                                              self.num_sparse,
                                              self.embedding_dim)
         self.fc = nn.Linear(dnn_hidden_units[-1] + num_subspaces * self.embedding_dim, 1)
+        self.apply(self._init_weights)
 
 
     def forward(self, data):
