@@ -7,9 +7,9 @@ from torch import nn
 import torch
 from ..layers import EmbeddingLayer, MLP_Layer, LR_Layer, MultiHeadSelfAttention
 from ..utils import get_feature_num, get_linear_input
+from ..base_model import BaseModel
 
-
-class AutoInt(nn.Module):
+class AutoInt(BaseModel):
     def __init__(self,
                  embedding_dim=32,
                  dnn_hidden_units=[64, 64, 64],
@@ -18,14 +18,12 @@ class AutoInt(nn.Module):
                  attention_dim = 8,
                  loss_fun='torch.nn.BCELoss()',
                  enc_dict=None):
-        super(AutoInt, self).__init__()
+        super(AutoInt, self).__init__(enc_dict,embedding_dim)
 
-        self.embedding_dim = embedding_dim
         self.dnn_hidden_units = dnn_hidden_units
         self.loss_fun = eval(loss_fun)
         self.enc_dict = enc_dict
 
-        self.embedding_layer = EmbeddingLayer(enc_dict=self.enc_dict, embedding_dim=self.embedding_dim)
         self.num_sparse, self.num_dense = get_feature_num(self.enc_dict)
 
         self.lr_layer = LR_Layer(enc_dict=enc_dict)
@@ -41,6 +39,7 @@ class AutoInt(nn.Module):
                                      align_to="output")
               for i in range(attention_layers)])
         self.fc = nn.Linear(self.num_sparse * attention_dim * num_heads, 1)
+        self.apply(self._init_weights)
 
     def forward(self, data):
 
