@@ -7,8 +7,8 @@ from torch import nn
 import torch
 from ..layers import EmbeddingLayer, MLP_Layer, KMaxPooling, get_activation
 from ..utils import get_feature_num, get_linear_input
-
-class CCPM(nn.Module):
+from ..base_model import BaseModel
+class CCPM(BaseModel):
     def __init__(self,
                  embedding_dim=32,
                  dnn_hidden_units=[64, 64, 64],
@@ -16,14 +16,12 @@ class CCPM(nn.Module):
                  kernel_heights=[6, 5, 3],
                  loss_fun='torch.nn.BCELoss()',
                  enc_dict=None):
-        super(CCPM, self).__init__()
+        super(CCPM, self).__init__(enc_dict,embedding_dim)
 
-        self.embedding_dim = embedding_dim
         self.dnn_hidden_units = dnn_hidden_units
         self.loss_fun = eval(loss_fun)
         self.enc_dict = enc_dict
 
-        self.embedding_layer = EmbeddingLayer(enc_dict=self.enc_dict, embedding_dim=self.embedding_dim)
         self.num_sparse, self.num_dense = get_feature_num(self.enc_dict)
 
         self.conv_layer = CCPM_ConvLayer(self.num_sparse,
@@ -32,6 +30,8 @@ class CCPM(nn.Module):
         conv_out_dim = 3 * embedding_dim * channels[-1]  # 3 is k-max-pooling size of the last layer
         self.fc = nn.Linear(conv_out_dim, 1)
 
+        self.apply(self._init_weights)
+
     def forward(self, data):
 
         feature_emb = self.embedding_layer(data)
