@@ -7,21 +7,19 @@ from torch import nn
 import torch
 from ..layers import EmbeddingLayer, LR_Layer, MLP_Layer, BilinearInteractionLayer, SENET_Layer
 from ..utils import get_feature_num, get_linear_input
-
-class FiBiNet(nn.Module):
+from ..base_model import BaseModel
+class FiBiNet(BaseModel):
     def __init__(self,
                  embedding_dim=32,
                  hidden_units=[64, 64, 64],
                  loss_fun='torch.nn.BCELoss()',
                  enc_dict=None):
-        super(FiBiNet, self).__init__()
+        super(FiBiNet, self).__init__(enc_dict,embedding_dim)
 
-        self.embedding_dim = embedding_dim
         self.hidden_units = hidden_units
         self.loss_fun = eval(loss_fun)
         self.enc_dict = enc_dict
 
-        self.embedding_layer = EmbeddingLayer(enc_dict=self.enc_dict, embedding_dim=self.embedding_dim)
         self.num_sparse, self.num_dense = get_feature_num(self.enc_dict)
 
         self.lr = LR_Layer(enc_dict=self.enc_dict)
@@ -31,6 +29,7 @@ class FiBiNet(nn.Module):
         input_dim = self.num_sparse * (self.num_sparse - 1) * self.embedding_dim + self.num_dense
         self.dnn = MLP_Layer(input_dim=input_dim, output_dim=1, hidden_units=self.hidden_units,
                              hidden_activations='relu', dropout_rates=0)
+        self.apply(self._init_weights)
 
     def forward(self, data):
         y_pred = self.lr(data)  # Batch,1
