@@ -7,21 +7,20 @@ from torch import nn
 import torch
 from ..layers import EmbeddingLayer, MLP_Layer, FM_Layer
 from ..utils import get_feature_num, get_linear_input
-
-class FM(nn.Module):
+from ..base_model import BaseModel
+class FM(BaseModel):
     def __init__(self,
                  embedding_dim=32,
                  loss_fun='torch.nn.BCELoss()',
                  enc_dict=None):
-        super(FM, self).__init__()
+        super(FM, self).__init__(enc_dict,embedding_dim)
 
-        self.embedding_dim = embedding_dim
         self.loss_fun = eval(loss_fun)
         self.enc_dict = enc_dict
-
-        self.embedding_layer = EmbeddingLayer(enc_dict=self.enc_dict, embedding_dim=self.embedding_dim)
         self.fm = FM_Layer()
 
+        self.apply(self._init_weights)
+
     def forward(self, data):
         feature_emb = self.embedding_layer(data)
         y_pred = self.fm(feature_emb)
