@@ -7,28 +7,26 @@ from torch import nn
 import torch
 from ..layers import EmbeddingLayer, LR_Layer, MLP_Layer, InnerProductLayer
 from ..utils import get_dnn_input_dim
-
-class NFM(nn.Module):
+from ..base_model import BaseModel
+class NFM(BaseModel):
     def __init__(self,
                  embedding_dim=32,
                  hidden_units=[64, 64, 64],
                  loss_fun='torch.nn.BCELoss()',
                  enc_dict=None):
-        super(NFM, self).__init__()
+        super(NFM, self).__init__(enc_dict,embedding_dim)
 
-        self.embedding_dim = embedding_dim
         self.hidden_units = hidden_units
         self.loss_fun = eval(loss_fun)
         self.enc_dict = enc_dict
 
-        self.embedding_layer = EmbeddingLayer(enc_dict=self.enc_dict, embedding_dim=self.embedding_dim)
-
         self.lr = LR_Layer(enc_dict=self.enc_dict)
 
         self.inner_product_layer = InnerProductLayer(output="Bi_interaction_pooling")
         self.dnn_input_dim = get_dnn_input_dim(self.enc_dict, self.embedding_dim)
         self.dnn = MLP_Layer(input_dim=self.embedding_dim, output_dim=1, hidden_units=self.hidden_units,
                              hidden_activations='relu', dropout_rates=0)
+        self.apply(self._init_weights)
 
     def forward(self, data):
         y_pred = self.lr(data)  # Batch,1
