@@ -7,27 +7,25 @@ import torch
 from torch import nn
 from ..layers import EmbeddingLayer, MLP_Layer, LR_Layer
 from ..utils import get_dnn_input_dim, get_linear_input
-
-class WDL(nn.Module):
+from ..base_model import BaseModel
+class WDL(BaseModel):
     def __init__(self,
                  embedding_dim=32,
                  hidden_units=[64, 64, 64],
                  loss_fun='torch.nn.BCELoss()',
                  enc_dict=None):
-        super(WDL, self).__init__()
+        super(WDL, self).__init__(enc_dict,embedding_dim)
 
-        self.embedding_dim = embedding_dim
         self.hidden_units = hidden_units
         self.loss_fun = eval(loss_fun)
         self.enc_dict = enc_dict
-
-        self.embedding_layer = EmbeddingLayer(enc_dict=self.enc_dict, embedding_dim=self.embedding_dim)
         # Wide部分
         self.lr = LR_Layer(enc_dict=self.enc_dict)
         # Deep部分
         self.dnn_input_dim = get_dnn_input_dim(self.enc_dict, self.embedding_dim)
         self.dnn = MLP_Layer(input_dim=self.dnn_input_dim, output_dim=1, hidden_units=self.hidden_units,
                              hidden_activations='relu', dropout_rates=0)
+        self.apply(self._init_weights)
 
     def forward(self, data):
         # Wide
